@@ -3,7 +3,6 @@ from pathlib import Path
 
 import click
 from click.testing import CliRunner
-import pytest
 
 from ..command import download
 from ...consts import dandiset_metadata_file
@@ -16,7 +15,7 @@ def test_download_defaults(mocker):
     mock_download.assert_called_once_with(
         (),
         os.curdir,
-        existing="refresh",
+        existing="error",
         format="pyout",
         jobs=6,
         get_metadata=True,
@@ -32,7 +31,7 @@ def test_download_all_types(mocker):
     mock_download.assert_called_once_with(
         (),
         os.curdir,
-        existing="refresh",
+        existing="error",
         format="pyout",
         jobs=6,
         get_metadata=True,
@@ -48,7 +47,7 @@ def test_download_metadata_only(mocker):
     mock_download.assert_called_once_with(
         (),
         os.curdir,
-        existing="refresh",
+        existing="error",
         format="pyout",
         jobs=6,
         get_metadata=True,
@@ -64,7 +63,7 @@ def test_download_assets_only(mocker):
     mock_download.assert_called_once_with(
         (),
         os.curdir,
-        existing="refresh",
+        existing="error",
         format="pyout",
         jobs=6,
         get_metadata=False,
@@ -82,9 +81,6 @@ def test_download_bad_type(mocker):
     mock_download.assert_not_called()
 
 
-@pytest.mark.skipif(
-    not os.environ.get("DANDI_DEVEL"), reason="DANDI_DEVEL required to run"
-)
 def test_download_gui_instance_in_dandiset(mocker):
     mock_download = mocker.patch("dandi.download.download")
     runner = CliRunner()
@@ -95,7 +91,7 @@ def test_download_gui_instance_in_dandiset(mocker):
     mock_download.assert_called_once_with(
         ["https://gui.dandiarchive.org/#/dandiset/123456/draft"],
         os.curdir,
-        existing="refresh",
+        existing="error",
         format="pyout",
         jobs=6,
         get_metadata=True,
@@ -104,9 +100,6 @@ def test_download_gui_instance_in_dandiset(mocker):
     )
 
 
-@pytest.mark.skipif(
-    not os.environ.get("DANDI_DEVEL"), reason="DANDI_DEVEL required to run"
-)
 def test_download_api_instance_in_dandiset(mocker):
     mock_download = mocker.patch("dandi.download.download")
     runner = CliRunner()
@@ -117,7 +110,7 @@ def test_download_api_instance_in_dandiset(mocker):
     mock_download.assert_called_once_with(
         ["http://localhost:8000/api/dandisets/123456/"],
         os.curdir,
-        existing="refresh",
+        existing="error",
         format="pyout",
         jobs=6,
         get_metadata=True,
@@ -126,9 +119,6 @@ def test_download_api_instance_in_dandiset(mocker):
     )
 
 
-@pytest.mark.skipif(
-    not os.environ.get("DANDI_DEVEL"), reason="DANDI_DEVEL required to run"
-)
 def test_download_url_instance_match(mocker):
     mock_download = mocker.patch("dandi.download.download")
     r = CliRunner().invoke(
@@ -143,7 +133,7 @@ def test_download_url_instance_match(mocker):
     mock_download.assert_called_once_with(
         ("http://localhost:8000/api/dandisets/123456/",),
         os.curdir,
-        existing="refresh",
+        existing="error",
         format="pyout",
         jobs=6,
         get_metadata=True,
@@ -152,9 +142,6 @@ def test_download_url_instance_match(mocker):
     )
 
 
-@pytest.mark.skipif(
-    not os.environ.get("DANDI_DEVEL"), reason="DANDI_DEVEL required to run"
-)
 def test_download_url_instance_conflict(mocker):
     mock_download = mocker.patch("dandi.download.download")
     r = CliRunner().invoke(
@@ -163,7 +150,7 @@ def test_download_url_instance_conflict(mocker):
         standalone_mode=False,
     )
     assert r.exit_code != 0
-    assert isinstance(r.exception, click.UsageError)
+    assert isinstance(r.exception, click.ClickException)
     assert (
         str(r.exception)
         == "http://localhost:8000/api/dandisets/123456/ does not point to 'dandi' instance"
